### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [v0.11.2](https://github.com/nevermined-io/sdk-py/compare/v0.11.1...v0.11.2)

> 1 February 2022

- contract lib version [`#61`](https://github.com/nevermined-io/sdk-py/pull/61)
- Adding v0.11.1 Changelog updates [`74a4ca0`](https://github.com/nevermined-io/sdk-py/commit/74a4ca08b6528ee92c4bf361e884b88e738321d4)
- fix test [`6813c96`](https://github.com/nevermined-io/sdk-py/commit/6813c96d7bf4d249739c2f873e25f9d239ad630c)
- test response [`99bb9a1`](https://github.com/nevermined-io/sdk-py/commit/99bb9a142704f8d38de55513bfec4f7a39549c17)

#### [v0.11.1](https://github.com/nevermined-io/sdk-py/compare/v0.11.0...v0.11.1)

> 24 January 2022

- commons utils version [`#60`](https://github.com/nevermined-io/sdk-py/pull/60)
- Adding v0.11.0 Changelog updates [`1e88726`](https://github.com/nevermined-io/sdk-py/commit/1e8872688c7181d502d2647f81cfc9786f771f22)

#### [v0.11.0](https://github.com/nevermined-io/sdk-py/compare/v0.10.7...v0.11.0)

> 22 December 2021

- Updated version of contracts-lib [`#59`](https://github.com/nevermined-io/sdk-py/pull/59)
- Adding data transfer proofs here [`#50`](https://github.com/nevermined-io/sdk-py/pull/50)
- key transfer working here too [`23475ed`](https://github.com/nevermined-io/sdk-py/commit/23475ed511855033c0f6ef3afa6d739efd797035)
- timeout params [`93ec664`](https://github.com/nevermined-io/sdk-py/commit/93ec664fdbd80d5acd96852ac5664a8686a3868e)
- Added NFTUpgradeable changes [`4475013`](https://github.com/nevermined-io/sdk-py/commit/4475013e30c9e021b754edd3ae9c5fc9f3edfdd1)

#### [v0.10.7](https://github.com/nevermined-io/sdk-py/compare/v0.10.6...v0.10.7)

> 8 October 2021

- Make AccessProof contracts optional [`#55`](https://github.com/nevermined-io/sdk-py/pull/55)
- Adding v0.10.6 Changelog updates [`be0f22f`](https://github.com/nevermined-io/sdk-py/commit/be0f22f0a0412609aa77cbbd45bb6bd35dd3dc0a)

#### [v0.10.6](https://github.com/nevermined-io/sdk-py/compare/v0.10.5...v0.10.6)

> 8 October 2021

- Set tokenAddress when creating an asset [`#54`](https://github.com/nevermined-io/sdk-py/pull/54)
- Fix failing test [`f7f100c`](https://github.com/nevermined-io/sdk-py/commit/f7f100c69d5cf2b10f1527f5face828cec91798c)
- Set default tokenAddress [`0717a00`](https://github.com/nevermined-io/sdk-py/commit/0717a00716b01281bdce83a7c82e525bccfd0b35)
- bump version [`9257801`](https://github.com/nevermined-io/sdk-py/commit/9257801a0c429231748602e43350f318dcff94b6)

#### [v0.10.5](https://github.com/nevermined-io/sdk-py/compare/v0.10.4...v0.10.5)

> 30 September 2021

- Feature/contracts 1.1.8 [`#52`](https://github.com/nevermined-io/sdk-py/pull/52)
- support aurora networks [`#51`](https://github.com/nevermined-io/sdk-py/pull/51)
- Bump version: 0.10.4 → 0.10.5 [`900b2cf`](https://github.com/nevermined-io/sdk-py/commit/900b2cf8cd7f33ed3daead72aea6d8193de69a27)
- Upgrade version to 1.1.8 [`a871249`](https://github.com/nevermined-io/sdk-py/commit/a871249e2000016f5fa9b7e1e8b935208f409221)

#### [v0.10.4](https://github.com/nevermined-io/sdk-py/compare/v0.10.3...v0.10.4)

> 22 September 2021

- Bump version: 0.10.3 → 0.10.4 [`083f243`](https://github.com/nevermined-io/sdk-py/commit/083f2439390fb773c21585bd630cc5b4702988ea)
- update [`fde6e4c`](https://github.com/nevermined-io/sdk-py/commit/fde6e4c0c012cbfb32a18577fd2c62d5d2b6ad92)

#### [v0.10.3](https://github.com/nevermined-io/sdk-py/compare/v0.10.2...v0.10.3)

> 21 September 2021

- Adding v0.10.2 Changelog updates [`4ef3089`](https://github.com/nevermined-io/sdk-py/commit/4ef3089dddda4123497658d9e104d5de17424618)
- Bump version: 0.10.2 → 0.10.3 [`07d7778`](https://github.com/nevermined-io/sdk-py/commit/07d7778fb74224167d5eb39c59e59ab7ff6c434a)
- fix version [`5e4fcb5`](https://github.com/nevermined-io/sdk-py/commit/5e4fcb57d633776caaaafabfd81eadd109c1d9b5)

#### [v0.10.2](https://github.com/nevermined-io/sdk-py/compare/v0.10.1...v0.10.2)

> 9 September 2021

- Test E2E with mumbai [`#49`](https://github.com/nevermined-io/sdk-py/pull/49)
- Cleaned up test config [`6b3ea86`](https://github.com/nevermined-io/sdk-py/commit/6b3ea8639e1cc4423a83ccac394004a2d67922c5)
- Adding v0.10.1 Changelog updates [`5f009bf`](https://github.com/nevermined-io/sdk-py/commit/5f009bf32e077acb7a269000949fad72e1d5b7da)
- bump version [`720c4c0`](https://github.com/nevermined-io/sdk-py/commit/720c4c0ff5acc41769e9d968a1cfdcb895b98044)

#### [v0.10.1](https://github.com/nevermined-io/sdk-py/compare/v0.10.0...v0.10.1)

> 8 September 2021

- Loads pre-packaged artifacts by default [`#47`](https://github.com/nevermined-io/sdk-py/pull/47)
- Fix metadata tests [`cdfc8a4`](https://github.com/nevermined-io/sdk-py/commit/cdfc8a413875b1aee350555cf28049ead5b4e401)
- Fix metadata tests [`c277f25`](https://github.com/nevermined-io/sdk-py/commit/c277f2574a8be12a91eccbb5065428b67f06e56e)
- Adding v0.10.0 Changelog updates [`1a4177e`](https://github.com/nevermined-io/sdk-py/commit/1a4177e7f2ecfc17ac047561c90ac5c8f1066262)

#### [v0.10.0](https://github.com/nevermined-io/sdk-py/compare/v0.9.0...v0.10.0)

> 25 May 2021

- Bringing NFTs support [`#43`](https://github.com/nevermined-io/sdk-py/pull/43)
- implementing nft access flow [`ba926dc`](https://github.com/nevermined-io/sdk-py/commit/ba926dc8220bc2145c191cf225a0604d02168184)
- Using last versions to fix the NFTs flow [`c5bd0d1`](https://github.com/nevermined-io/sdk-py/commit/c5bd0d1200b19fcb0e34a42b80c6d56a89ac040b)
- Extracting NFTs capabilities to a specific `nft` api [`f2e4f4e`](https://github.com/nevermined-io/sdk-py/commit/f2e4f4e6106d06895dcea8972e3cf9e76bbb7039)

#### [v0.9.0](https://github.com/nevermined-io/sdk-py/compare/v0.9.0-rc0...v0.9.0)

> 6 April 2021

- Migration to contracts v1.0 [`#42`](https://github.com/nevermined-io/sdk-py/pull/42)
- Adding v0.9.0-rc0 Changelog updates [`d52eeee`](https://github.com/nevermined-io/sdk-py/commit/d52eeeed1651b803b0be41da7f5ee6b2b7394376)
- updating version [`9c1a636`](https://github.com/nevermined-io/sdk-py/commit/9c1a63612f1a38a1991153d18e6ab402827b2488)
- removing events handler [`d794f86`](https://github.com/nevermined-io/sdk-py/commit/d794f868cb925b8be2613f0f77db2f3f0d6788ff)

#### [v0.9.0-rc0](https://github.com/nevermined-io/sdk-py/compare/v0.8.0...v0.9.0-rc0)

> 6 April 2021

- Added integration with Filecoin [`#41`](https://github.com/nevermined-io/sdk-py/pull/41)
- Test with pre-compiled contracts [`#38`](https://github.com/nevermined-io/sdk-py/pull/38)
- Migration to contracts v1.0 [`72ba6b6`](https://github.com/nevermined-io/sdk-py/commit/72ba6b6e571db30bafe212274c2953f276bf7b68)
- Revert "Test chaching dockerlib" [`b241e27`](https://github.com/nevermined-io/sdk-py/commit/b241e274884ce11a3097c8c13cc65b1f7f839987)
- Test chaching dockerlib [`a88c672`](https://github.com/nevermined-io/sdk-py/commit/a88c6725e297d47d69c1198301f542578b5494d9)

#### [v0.8.0](https://github.com/nevermined-io/sdk-py/compare/v0.7.0...v0.8.0)

> 11 February 2021

- Implementation of multiple receivers for rewards distribution [`#39`](https://github.com/nevermined-io/sdk-py/pull/39)
- Adding v0.7.0 Changelog updates [`edc5fa9`](https://github.com/nevermined-io/sdk-py/commit/edc5fa9d9af997890574fffcb46bbb108bf5d736)

#### [v0.7.0](https://github.com/nevermined-io/sdk-py/compare/v0.6.0...v0.7.0)

> 6 January 2021

- Start update agreements api [`#37`](https://github.com/nevermined-io/sdk-py/pull/37)
- Update accounts api [`#36`](https://github.com/nevermined-io/sdk-py/pull/36)
- Add nft methods [`#31`](https://github.com/nevermined-io/sdk-py/pull/31)
- Fix tests [`5616eaa`](https://github.com/nevermined-io/sdk-py/commit/5616eaaf1c9bbc44df47e09bd342024302e40163)
- Remove signature in agreements methods [`c1f606a`](https://github.com/nevermined-io/sdk-py/commit/c1f606a963444f37bdc554f0dd29ae8eb4f6044d)
- Add 3 missed methods for templates [`f9f439d`](https://github.com/nevermined-io/sdk-py/commit/f9f439d8f5d118d83e1bebe2a0ca3e5fffb47a21)

#### [v0.6.0](https://github.com/nevermined-io/sdk-py/compare/v0.5.0...v0.6.0)

> 7 December 2020

- Use commons convert method [`#30`](https://github.com/nevermined-io/sdk-py/pull/30)
- Added jwt support [`#29`](https://github.com/nevermined-io/sdk-py/pull/29)
- Implement provenance methods [`#28`](https://github.com/nevermined-io/sdk-py/pull/28)
- Fixed failing tests [`3b6895a`](https://github.com/nevermined-io/sdk-py/commit/3b6895a571111e24f861952b74c389387d5d22b9)
- Added oauth support for execute endpoint [`54e3b5c`](https://github.com/nevermined-io/sdk-py/commit/54e3b5c114d00e5cfdac22bd2862cab523387ec3)
- Added oauth support for compute status endpoint [`76f4a06`](https://github.com/nevermined-io/sdk-py/commit/76f4a0608a9d2852c38d5e4521a7521c21a39c6e)

#### [v0.5.0](https://github.com/nevermined-io/sdk-py/compare/v0.4.2...v0.5.0)

> 6 November 2020

- Fixed tests with correct links to in metadata [`#25`](https://github.com/nevermined-io/sdk-py/pull/25)
- new org [`3da2a4d`](https://github.com/nevermined-io/sdk-py/commit/3da2a4d49012fbffafe26c96176c1013bf803972)
- Revert "Bump version: 0.5.0 → 0.6.0" [`5418107`](https://github.com/nevermined-io/sdk-py/commit/54181073474a9311bdc7cd8fe0abfa28ba8b7c19)
- Bump version: 0.5.0 → 0.6.0 [`7307bfc`](https://github.com/nevermined-io/sdk-py/commit/7307bfce3e9895d5fd78188e2b16322dedb6a32c)

#### [v0.4.2](https://github.com/nevermined-io/sdk-py/compare/v0.4.1...v0.4.2)

> 22 September 2020

- Don't use http query parameters in filename [`#24`](https://github.com/nevermined-io/sdk-py/pull/24)
- Skip http query parameters when getting the filename to download [`05c3679`](https://github.com/nevermined-io/sdk-py/commit/05c36793234492b28989145346eae30b896c3f80)
- Bump version: 0.4.1 → 0.4.2 [`b902009`](https://github.com/nevermined-io/sdk-py/commit/b902009fc21ee0614fcf9345c56e960087d44bca)

#### [v0.4.1](https://github.com/nevermined-io/sdk-py/compare/v0.4.0...v0.4.1)

> 21 September 2020

- Return the compute job id [`#23`](https://github.com/nevermined-io/sdk-py/pull/23)
- Added support for the gateway compute logs and compute status endpoints [`#21`](https://github.com/nevermined-io/sdk-py/pull/21)
- refresh word_count.py url [`#19`](https://github.com/nevermined-io/sdk-py/pull/19)
- `assets.execute` now returns the id of the compute job [`ebf7a8d`](https://github.com/nevermined-io/sdk-py/commit/ebf7a8d80a61dcaebeaf0859d642028e9bc9fe37)
- Bump version: 0.4.0 → 0.4.1 [`5349345`](https://github.com/nevermined-io/sdk-py/commit/5349345adb9e59fcf5a04283ceb8b0c2601a076f)
- Fix gateway mock on tests [`d24a722`](https://github.com/nevermined-io/sdk-py/commit/d24a722b1dcd3b6d9bc1d3d1f8d82106f9aee243)

#### [v0.4.0](https://github.com/nevermined-io/sdk-py/compare/v0.3.0...v0.4.0)

> 11 September 2020

- Added support for creating compute ddo with files [`#18`](https://github.com/nevermined-io/sdk-py/pull/18)
- Feature/compute example [`#15`](https://github.com/nevermined-io/sdk-py/pull/15)
- Upgrading to new contracts v0.4 [`#16`](https://github.com/nevermined-io/sdk-py/pull/16)
- Updated asset executor to call the new gateway endpoint [`#11`](https://github.com/nevermined-io/sdk-py/pull/11)
- Integration of compute case [`fa9fe2f`](https://github.com/nevermined-io/sdk-py/commit/fa9fe2f1b1e7f7dabb135d634d919541e198f06a)
- Added tests for the download endpoint [`6699ce7`](https://github.com/nevermined-io/sdk-py/commit/6699ce762f53b2a6da7085f33916b8f8e33dcac1)
- Refactored compute example to work with the changes in the compute api [`bb14600`](https://github.com/nevermined-io/sdk-py/commit/bb146007a41525ad87ff72b26fde06d6f6243561)

#### [v0.3.0](https://github.com/nevermined-io/sdk-py/compare/v0.2.0...v0.3.0)

> 15 May 2020

- Feature/update to remove secret store [`#10`](https://github.com/nevermined-io/sdk-py/pull/10)
- Adds a .nojekyll file for docs builds [`#9`](https://github.com/nevermined-io/sdk-py/pull/9)
- Upgrade web3py version libraries [`#8`](https://github.com/nevermined-io/sdk-py/pull/8)
- Implementation of new flow [`#7`](https://github.com/nevermined-io/sdk-py/pull/7)
- Update changelog [`bd34938`](https://github.com/nevermined-io/sdk-py/commit/bd349384c17f53ed79c0e3f996d5eedadc43cfa6)
- Update sdk to support new authorization methods [`c18910c`](https://github.com/nevermined-io/sdk-py/commit/c18910cd877cd2b5001c828347f943ccf4f1738d)
- secret store working with the new authorization structure [`27ba0e3`](https://github.com/nevermined-io/sdk-py/commit/27ba0e3752f6fa410caf5d9d9ff7497954d5c19a)

#### [v0.2.0](https://github.com/nevermined-io/sdk-py/compare/v0.1.0...v0.2.0)

> 30 April 2020

- add release python workflow [`#3`](https://github.com/nevermined-io/sdk-py/pull/3)
- Udpate names to nevermined [`#5`](https://github.com/nevermined-io/sdk-py/pull/5)
- Update templates for release and remove old references to squid [`fd02d43`](https://github.com/nevermined-io/sdk-py/commit/fd02d4345d4682637db5331ca5522e3437b3a01e)
- Bump version: 0.1.0 → 0.2.0 [`475763d`](https://github.com/nevermined-io/sdk-py/commit/475763db5146c939d4d1367805d8fd5f6d430ab8)
- Update events-handler version [`44883f6`](https://github.com/nevermined-io/sdk-py/commit/44883f66054384e730bc00f08fe1cc5d6acac181)

#### v0.1.0

> 29 April 2020

- Feature/use common ddos [`#2`](https://github.com/nevermined-io/sdk-py/pull/2)
- Feature/update names brizo and aquarius [`#1`](https://github.com/nevermined-io/sdk-py/pull/1)
- First commit [`030cfb1`](https://github.com/nevermined-io/sdk-py/commit/030cfb162f7df06a8af520ad484ed329ac0254cd)
- Working with remote ddos and did:nv [`76340a9`](https://github.com/nevermined-io/sdk-py/commit/76340a955376b93457888f99d6c58751c5359f6d)
- Renaming [`249c0b6`](https://github.com/nevermined-io/sdk-py/commit/249c0b67e3b888a7916368374827a579ee719018)
